DivList<T> class

Inheritance

Constructors

DivList({Key? key, required Future<bool> onLoad(int page, List<T> items, bool refresh), required Widget itemBuilder(BuildContext context, T item, int index), Widget headerBuilder(BuildContext context, List<T> items)?, Widget footerBuilder(BuildContext context, List<T> items)?, void init()?, ScrollPhysics? physics = const AlwaysScrollableScrollPhysics(), bool refresh = true, DivListData<T>? data, DivListStatus status = const DivListStatus(), bool reverse = false, bool shrinkWrap = false, ScrollController? controller, bool primary = false})
const

Properties

controller ScrollController?
final
data DivListData<T>?
final
footerBuilder Widget Function(BuildContext context, List<T> items)?
final
hashCode int
The hash code for this object.
no setterinherited
headerBuilder Widget Function(BuildContext context, List<T> items)?
final
init → void Function()?
final
itemBuilder Widget Function(BuildContext context, T item, int index)
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onLoad Future<bool> Function(int page, List<T> items, bool refresh)
返回 false 说明没有更多数据了
final
physics ScrollPhysics?
final
primary bool
final
refresh bool
final
reverse bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shrinkWrap bool
final
status DivListStatus
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited