DivListStatus class

列表状态

Constructors

DivListStatus({Widget? none, Widget? more, Widget? noMore, Widget? loading, Widget? noData, TextStyle style = const TextStyle(fontSize: 12)})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
loading Widget?
final
more Widget?
final
noData Widget?
final
noMore Widget?
final
none Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TextStyle
final

Methods

builder(DivListStatusEnum status) Widget
渲染状态组件
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited